@@ -30,6 +30,10 @@ from allauth.account.forms import (
     UserTokenForm,
 )
 from allauth.account.internal import flows
+from allauth.account.internal.decorators import (
+    login_not_required,
+    login_stage_required,
+)
 from allauth.account.mixins import (
     AjaxCapableProcessFormViewMixin,
     CloseableSignupMixin,
@@ -49,7 +53,6 @@ from allauth.account.stages import (
     LoginStageController,
 )
 from allauth.account.utils import (
-    complete_signup,
     perform_login,
     send_email_confirmation,
     sync_user_email_addresses,
@@ -70,7 +73,6 @@ sensitive_post_parameters_m = method_decorator(
 )
 
 
-@method_decorator(rate_limit(action="login"), name="dispatch")
 class LoginView(
     NextRedirectMixin,
     RedirectAuthenticatedUserMixin,
@@ -81,6 +83,8 @@ class LoginView(
     template_name = "account/login." + app_settings.TEMPLATE_EXTENSION
     success_url = None
 
+    @method_decorator(rate_limit(action="login"))
+    @method_decorator(login_not_required)
     @sensitive_post_parameters_m
     @method_decorator(never_cache)
     def dispatch(self, request, *args, **kwargs):
@@ -136,7 +140,6 @@ class LoginView(
 login = LoginView.as_view()
 
 
-@method_decorator(rate_limit(action="signup"), name="dispatch")
 class SignupView(
     RedirectAuthenticatedUserMixin,
     CloseableSignupMixin,
@@ -147,6 +150,8 @@ class SignupView(
     template_name = "account/signup." + app_settings.TEMPLATE_EXTENSION
     form_class = SignupForm
 
+    @method_decorator(rate_limit(action="signup"))
+    @method_decorator(login_not_required)
     @sensitive_post_parameters_m
     @method_decorator(never_cache)
     def dispatch(self, request, *args, **kwargs):
@@ -161,17 +166,22 @@ class SignupView(
             return resp
         try:
             redirect_url = self.get_success_url()
-            return complete_signup(
+            return flows.signup.complete_signup(
                 self.request,
-                self.user,
-                email_verification=None,
-                success_url=redirect_url,
+                user=self.user,
+                redirect_url=redirect_url,
+                by_passkey=form.by_passkey,
             )
         except ImmediateHttpResponse as e:
             return e.response
 
     def get_context_data(self, **kwargs):
         ret = super().get_context_data(**kwargs)
+        passkey_signup_enabled = False
+        if allauth_app_settings.MFA_ENABLED:
+            from allauth.mfa import app_settings as mfa_settings
+
+            passkey_signup_enabled = mfa_settings.PASSKEY_SIGNUP_ENABLED
         form = ret["form"]
         email = self.request.session.get("account_verified_email")
         if email:
@@ -181,13 +191,22 @@ class SignupView(
             for email_key in email_keys:
                 form.fields[email_key].initial = email
         login_url = self.passthrough_next_url(reverse("account_login"))
+        signup_url = self.passthrough_next_url(reverse("account_signup"))
+        signup_by_passkey_url = None
+        if passkey_signup_enabled:
+            signup_by_passkey_url = self.passthrough_next_url(
+                reverse("account_signup_by_passkey")
+            )
         site = get_current_site(self.request)
         ret.update(
             {
                 "login_url": login_url,
+                "signup_url": signup_url,
+                "signup_by_passkey_url": signup_by_passkey_url,
                 "site": site,
                 "SOCIALACCOUNT_ENABLED": allauth_app_settings.SOCIALACCOUNT_ENABLED,
                 "SOCIALACCOUNT_ONLY": allauth_app_settings.SOCIALACCOUNT_ONLY,
+                "PASSKEY_SIGNUP_ENABLED": passkey_signup_enabled,
             }
         )
         return ret
@@ -209,6 +228,19 @@ class SignupView(
 signup = SignupView.as_view()
 
 
+class SignupByPasskeyView(SignupView):
+    template_name = "account/signup_by_passkey." + app_settings.TEMPLATE_EXTENSION
+
+    def get_form_kwargs(self):
+        ret = super().get_form_kwargs()
+        ret["by_passkey"] = True
+        return ret
+
+
+signup_by_passkey = SignupByPasskeyView.as_view()
+
+
+@method_decorator(login_not_required, name="dispatch")
 class ConfirmEmailView(NextRedirectMixin, LogoutFunctionalityMixin, TemplateView):
     template_name = "account/email_confirm." + app_settings.TEMPLATE_EXTENSION
 
@@ -530,6 +562,7 @@ class PasswordSetView(AjaxCapableProcessFormViewMixin, NextRedirectMixin, FormVi
 password_set = PasswordSetView.as_view()
 
 
+@method_decorator(login_not_required, name="dispatch")
 class PasswordResetView(NextRedirectMixin, AjaxCapableProcessFormViewMixin, FormView):
     template_name = "account/password_reset." + app_settings.TEMPLATE_EXTENSION
     form_class = ResetPasswordForm
@@ -562,6 +595,7 @@ class PasswordResetView(NextRedirectMixin, AjaxCapableProcessFormViewMixin, Form
 password_reset = PasswordResetView.as_view()
 
 
+@method_decorator(login_not_required, name="dispatch")
 class PasswordResetDoneView(TemplateView):
     template_name = "account/password_reset_done." + app_settings.TEMPLATE_EXTENSION
 
@@ -570,6 +604,7 @@ password_reset_done = PasswordResetDoneView.as_view()
 
 
 @method_decorator(rate_limit(action="reset_password_from_key"), name="dispatch")
+@method_decorator(login_not_required, name="dispatch")
 class PasswordResetFromKeyView(
     AjaxCapableProcessFormViewMixin,
     NextRedirectMixin,
@@ -661,6 +696,7 @@ class PasswordResetFromKeyView(
 password_reset_from_key = PasswordResetFromKeyView.as_view()
 
 
+@method_decorator(login_not_required, name="dispatch")
 class PasswordResetFromKeyDoneView(TemplateView):
     template_name = (
         "account/password_reset_from_key_done." + app_settings.TEMPLATE_EXTENSION
@@ -685,8 +721,7 @@ class LogoutView(NextRedirectMixin, LogoutFunctionalityMixin, TemplateView):
 
     def post(self, *args, **kwargs):
         url = self.get_redirect_url()
-        if self.request.user.is_authenticated:
-            self.logout()
+        self.logout()
         response = redirect(url)
         return _ajax_response(self.request, response)
 
@@ -699,6 +734,7 @@ class LogoutView(NextRedirectMixin, LogoutFunctionalityMixin, TemplateView):
 logout = LogoutView.as_view()
 
 
+@method_decorator(login_not_required, name="dispatch")
 class AccountInactiveView(TemplateView):
     template_name = "account/account_inactive." + app_settings.TEMPLATE_EXTENSION
 
@@ -706,6 +742,7 @@ class AccountInactiveView(TemplateView):
 account_inactive = AccountInactiveView.as_view()
 
 
+@method_decorator(login_not_required, name="dispatch")
 class EmailVerificationSentView(TemplateView):
     template_name = "account/verification_sent." + app_settings.TEMPLATE_EXTENSION
 
@@ -759,9 +796,7 @@ class ConfirmEmailVerificationCodeView(FormView):
     def get_context_data(self, **kwargs):
         ret = super().get_context_data(**kwargs)
         ret["email"] = self.pending_verification["email"]
-        ret["cancel_url"] = (
-            reverse("account_login") if self.stage else reverse("account_email")
-        )
+        ret["cancel_url"] = None if self.stage else reverse("account_email")
         return ret
 
     def form_valid(self, form):
@@ -770,7 +805,13 @@ class ConfirmEmailVerificationCodeView(FormView):
             if not email_address:
                 return self.stage.abort()
             return self.stage.exit()
-        return HttpResponseRedirect(reverse("account_email"))
+        if not email_address:
+            url = reverse("account_email")
+        else:
+            url = get_adapter(self.request).get_email_verification_redirect_url(
+                email_address
+            )
+        return HttpResponseRedirect(url)
 
     def form_invalid(self, form):
         attempts_left = flows.email_verification_by_code.record_invalid_attempt(
@@ -787,6 +828,7 @@ class ConfirmEmailVerificationCodeView(FormView):
         return HttpResponseRedirect(reverse("account_login"))
 
 
+@method_decorator(login_not_required, name="dispatch")
 def email_verification_sent(request):
     if app_settings.EMAIL_VERIFICATION_BY_CODE_ENABLED:
         return ConfirmEmailVerificationCodeView.as_view()(request)
@@ -879,10 +921,6 @@ class RequestLoginCodeView(RedirectAuthenticatedUserMixin, NextRedirectMixin, Fo
     form_class = RequestLoginCodeForm
     template_name = "account/request_login_code." + app_settings.TEMPLATE_EXTENSION
 
-    @method_decorator(never_cache)
-    def dispatch(self, request, *args, **kwargs):
-        return super().dispatch(request, *args, **kwargs)
-
     def get_form_class(self):
         return get_form_class(app_settings.FORMS, "request_login_code", self.form_class)
 
@@ -907,20 +945,34 @@ class RequestLoginCodeView(RedirectAuthenticatedUserMixin, NextRedirectMixin, Fo
 request_login_code = RequestLoginCodeView.as_view()
 
 
-class ConfirmLoginCodeView(RedirectAuthenticatedUserMixin, NextRedirectMixin, FormView):
+def _login_by_code_urlname():
+    # NOTE: Having this as a method instead of a constant allows changing
+    # settings in test cases...
+    return (
+        "account_request_login_code"
+        if app_settings.LOGIN_BY_CODE_ENABLED
+        else "account_login"
+    )
+
+
+@method_decorator(
+    login_stage_required(
+        stage=LoginByCodeStage.key, redirect_urlname=(_login_by_code_urlname())
+    ),
+    name="dispatch",
+)
+class ConfirmLoginCodeView(NextRedirectMixin, FormView):
     form_class = ConfirmLoginCodeForm
     template_name = "account/confirm_login_code." + app_settings.TEMPLATE_EXTENSION
 
     @method_decorator(never_cache)
     def dispatch(self, request, *args, **kwargs):
-        self.stage = LoginStageController.enter(request, LoginByCodeStage.key)
-        if not self.stage:
-            return HttpResponseRedirect(reverse("account_request_login_code"))
+        self.stage = request._login_stage
         self.user, self.pending_login = flows.login_by_code.get_pending_login(
-            self.stage.login, peek=True
+            self.request, self.stage.login, peek=True
         )
         if not self.pending_login:
-            return HttpResponseRedirect(reverse("account_request_login_code"))
+            return HttpResponseRedirect(reverse(_login_by_code_urlname()))
         return super().dispatch(request, *args, **kwargs)
 
     def get_form_class(self):
@@ -951,7 +1003,7 @@ class ConfirmLoginCodeView(RedirectAuthenticatedUserMixin, NextRedirectMixin, Fo
         )
         return HttpResponseRedirect(
             reverse(
-                "account_request_login_code"
+                _login_by_code_urlname()
                 if self.pending_login["initiated_by_user"]
                 else "account_login"
             )
