@@ -1,5 +1,9 @@
+from typing import Any, Dict
+
 from django.forms.fields import Field
 
+from allauth.account.models import EmailAddress
+from allauth.account.utils import user_display, user_username
 from allauth.core.internal.adapter import BaseAdapter
 from allauth.headless import app_settings
 from allauth.utils import import_attribute
@@ -26,6 +30,25 @@ class DefaultHeadlessAdapter(BaseAdapter):
         "invalid_url": "Invalid URL.",
     }
 
+    def serialize_user(self, user) -> Dict[str, Any]:
+        """
+        Returns the basic user data. Note that this data is also exposed in
+        partly authenticated scenario's (e.g. password reset, email
+        verification).
+        """
+        ret = {
+            "id": user.pk,
+            "display": user_display(user),
+            "has_usable_password": user.has_usable_password(),
+        }
+        email = EmailAddress.objects.get_primary_email(user)
+        if email:
+            ret["email"] = email
+        username = user_username(user)
+        if username:
+            ret["username"] = username
+        return ret
+
 
 def get_adapter():
     return import_attribute(app_settings.ADAPTER)()
